<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;

class PermissionController extends Controller
{
    protected $permission;

    public function __construct(Permission $permission)
    {
        $this->permission = $permission;
    }

    public function index()
    {
        
        return view("settings.permissions.index");
    }  
    
    public function data(Request $request)
    {
        $page = isset($request->pagesize) ? $request->pagesize : 25;
        if($page != 0){
            $permissions = Role::paginate($page);
        }else{
            $permissions = Role::all();
        }
        return response()->json([
            'status' => 'success',
            'permissions' => $permissions
        ]);
    }

    public function create(Request $request)
    {
        if($request->isMethod('post')){             
            $role = Role::create([
                'name' => $request->title,
                'slug' => Str::slug($request->title)
            ]);
            $this->permissions_create($request->permissions, $role->id);            
            return response()->json([
                'status' => 'success',
                'redirect' => route("app.setting.permission.edit", ['id' => $role->id])
            ]);
        }
        
        $permissions = config('permissions');        
        return view("settings.permissions.create", [
            "permissions" => $permissions
        ]);
    }

    public function edit(Request $request)
    {
        #dd($request->all());
        $roleId = $request->id;
        $role = Role::findById($roleId);
        
        if($request->isMethod('post')){
            $role->name = $request->title;
            $role->save();
                       
            $role->syncPermissions([]);
            $this->permissions_create($request->permissions, $role->id);

            return response()->json([
                'status' => 'success',
                'redirect' => route("app.setting.permission.edit", ['id' => $role->id])
            ]);
        }        
        
        $rolePermissions = $role->permissions->pluck('name')->toArray();
        $permissions = config('permissions'); // Permissions définies dans votre fichier permissions.php
        
        // Parcourez les permissions pour ajuster leur valeur selon celles assignées au rôle
        $this->setPermissionValues($permissions, $rolePermissions);                
        return view("settings.permissions.edit", [
            "permissions" => $permissions,
            "role" => $role
        ]);        
    }

    public function status(Request $request)
    {
        $id = $request->id;
        DB::table("permissions")->where("id", $id)->update([
            "status" => $request->status,
            "updated_at" => date_now()
        ]);
        return redirect()->route("app.setting.permission.index");
    }

    public function destroy($id)
    {
        DB::table("roles")->where("id", $id)->delete();
        return response()->json([
            'status' => 'success',
            'message' => 'Suppréssion éffectuée avec succès.',
        ]);
    }

    protected function permissions_create(Array $array, int $role_id) {
        $role = Role::find($role_id);   
        #dd($array);
        foreach ($array as $item) {
            // Récupérer l'ID de chaque élément
            $id = $item;    
            $permission = Permission::where('name', $id)->first();
            if (!$permission) {                
                $permission = Permission::create([
                    'name' => $id
                ]);
            }

            $role->givePermissionTo($permission);

            // Vérifier s'il existe des sous-éléments (enfants)
            if (isset($item['child']) && is_array($item['child'])) {
                // Appel récursif pour traiter les sous-éléments
                $this->permissions_create($item['child'], $role_id);
            }
        }
    
        return $role; // On retourne true après avoir traité tous les éléments
    }      
    
    protected function setPermissionValues(&$permissions, $rolePermissions)
    {
        foreach ($permissions as &$permission) {
            if (isset($permission['id']) && in_array($permission['id'], $rolePermissions)) {
                $permission['value'] = true;
            }

            if (isset($permission['child'])) {
                $this->setPermissionValues($permission['child'], $rolePermissions);
            }
        }
    }
}
