<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use modules\location\Models\Location;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;

class UserController extends Controller
{
    private $users;
    private $permissions;

    public function __construct(User $user, Permission $permission)
    {
        $this->users = $user;
        $this->permissions = $permission;
    }

    public function index(Request $request)
    {        
        $users = $this->users->users();        
        return view("settings.users.index", compact('users'));
    }

    public function create(Request $request)
    {
        $permissions = Role::all();
        $locations = Location::select('id', 'title')->where('type', 'site')->get()->toArray();
        $locations[] = [
            'id' => 0,
            'title' => 'TOUS LES SITES'
        ];
        return view("settings.users.create", compact('permissions', 'locations'));
    }

    public function store(Request $request)
    {
        $request->validate([
            "location.id" => "required",
            "permission_id" => "required|not_in:0",
            "name" => "required|unique:users,name",            
            "email" => "required|email|unique:users,email",            
            "password" => "required",
        ]);
        $user = $this->users->insertdata($request);
        return response()->json([
            'status' => 'success',
            'redirect' => route("app.setting.user.edit", ['id' => $user->id])
        ]);
    }

    public function edit(Request $request)
    {
        $user = $this->users->users(["id" => $request->id])[0];
        $permissions = Role::all();
        $locations = Location::select('id', 'title')->where('type', 'site')->get()->toArray();
        $locations[] = [
            'id' => 0,
            'title' => 'TOUS LES SITES'
        ];
        return view("settings.users.edit", compact('user', 'permissions', 'locations'));
    }


    public function update(Request $request)
    {
        $this->users->updatedata($request);
        return response()->json([
            'status' => 'success',
            'redirect' => route("app.setting.user.edit", ['id' => $request->id])
        ]);
    }

    public function destroy($id)
    {
        DB::table("users")->where("id", $id)->delete();
        return redirect()->route("app.setting.user.index");
    }
}
