<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Category extends Model
{
    use HasFactory;

    protected $table = "categories" ;
    protected $fillable = [
        'parent_id',
        'title',
        'code',
        'description',
        'position',
        'background',
        'color',
        'status',
        'image',
        'parent_marge',
        'created_at',
        'updated_at'
    ];

    public function parent(){
        return $this->belongsTo(Category::class, 'parent_id');
    }
    
    public function categories(){
        return $this->hasMany(Category::class, 'parent_id');
    }

    public function products()
    {
        return $this->belongsToMany(Products::class, 'products_categories', 'category_id', 'product_id');
    }

    public static function recursivescategories()
    {
        // Charge toutes les catégories avec leurs enfants
        $categories = Category::with('categories')->select('id', 'title', 'image')->whereNull('parent_id')->get();
        $structuredCategories = self::buildCategoryHierarchy($categories);
        return $structuredCategories;
    }

    private static function buildCategoryHierarchy($categories)
    {
        $result = [];

        foreach ($categories as $category) {
            $item = [
                'id' => $category->id,                         
                'title' => $category->title,
                'image' => $category->image,
                'parent_id' => $category->parent_id,
                'children' => self::buildCategoryHierarchy($category->categories)
            ];

            $result[] = $item;
        }

        return $result;
    }
}
