<?php

namespace modules\catalogs\Http\Controllers;

use App\Images;
use App\Rules\NotZero;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Carbon\Carbon;
use Maatwebsite\Excel\Facades\Excel;
use modules\catalogs\Exports\ProductExport;
use modules\catalogs\Models\Category;
use modules\catalogs\Models\Container;
use modules\catalogs\Models\HS;
use modules\catalogs\Models\ProductCategory;
use modules\catalogs\Models\ProductLocation;
use modules\catalogs\Models\ProductCustomerPrice;
use modules\catalogs\Models\ProductHS;
use modules\catalogs\Models\Products;
use modules\catalogs\Models\ProductStock;
use modules\catalogs\Models\ProductSubLocation;
use modules\catalogs\Models\ProductSupplierPrice;
use modules\catalogs\Models\Unite;
use modules\catalogs\services\ProductService;
use modules\catalogs\services\StockService;
use modules\crm\Models\BusinessContact;
use modules\crm\Models\CustomerGroup;
use modules\location\Models\Location;

class ProductController extends Controller
{

    public function auto_number($document, $num){
        $data = DB::table("numerotation")->where('description', $document)->first();
        #dd($data, $document);
        $format = $data->format;
        $date = Carbon::now();

        $n1 = explode('[#', $format);
        $n2 = explode('#]', $n1[1]);

        $n = substr($n2[0], 0, strlen($n2[0]) - strlen($num)) . $num;
        #dd($n, $data);
        $p1 = strpos($data->format, "[#") + 2;
        $p2 = strpos($data->format, "#]");
        $_n = substr($data->format, $p1, $p2 - $p1);

        $res1 = str_replace('[YYYY]', $date->format('Y'),
                    str_replace('[YY]', $date->format('y'),
                    str_replace('[MM]', $date->format('m'),
                    str_replace('[JJ]', $date->format('d'),
                    str_replace('[__]', "  ",
                    str_replace('[-]', "-",
                    str_replace('[_]', "_",
                    str_replace('[/]', "/",
                    str_replace('[°]', "°",
                    $format)))))))));

        $result = str_replace("[#$_n#]" , $n, $res1);
        #dd($result, $res1, $data->begin_num);
        return str_replace("[", "", str_replace("]", "", $result));
    }

    public function index(Request $request)
    {           
        /*$query = ProductLocation::with(['product.categories'])
            ->whereHas('product.categories', function ($q) {
                // Vérifier si la relation avec les catégories fonctionne
                $q->where('category_id', 1); // Remplace par un `category_id` que tu veux tester
            })
            ->whereHas('product.stock', function ($q) {
                // Vérifier si la relation avec les stocks fonctionne
                $q->where('location_id', 3); // Remplace par un `location_id` que tu veux tester
                $q->where('stock', '>', 0);
            })
            ->orderBy('products_locations.product_id') // Assurez-vous d'ordonner par un champ valide
            ->get();

        dd($query->toArray());*/

        if($request->ajax()){
            $categories = Category::recursivescategories();
            $unites = Unite::all();

            $p = Auth::user()->getAllPermissions();

            if(is_null(Auth::user()->location_id)){
                $locations = Location::select('id', 'title', 'stock_management')->where('status', 'active')->get();
            }else{
                $locations = Location::select('id', 'title', 'stock_management')->where('id', Auth::user()->location_id)->get();
            }            

            return response()->json([
                "status" => "success",
                "categories" => $categories,
                "locations" => array_merge($locations->toArray(), [['id' => 0, 'title' => 'Tous les sites', 'stock_management' => 1]]),
                "unites" => $unites,    
                "permissions" => $p
            ]);
        }
        

        return view("catalogs::product.index");
    }

    public function containers(Request $request){
        return response()->json([
            'status' => 'success',
            'containers' => Container::all()
        ]);
    }

    public function products(Request $request)
    { 
        if($request->slug){
            $slug = $request->slug;
            if($request->has('location')){
                $location_id = $request->location;
            }else{
                $location_id = my_location()->id;
            }

            if($slug == 'all'){
                $filter = ['location' => $location_id];
                $page = 0;                
                $products = ProductService::products($filter, $page);
            }else{
                $filter = ['location' => $location_id, 'slug' => $request->slug];
                if($request->has('with')){
                    $filter['with'] = $request->input('with');
                }                
                $res = ProductService::products($filter);
                $products = $request->has('one') ? $res->first() : $res;
                $products['location'] = Location::where('id', $location_id)->select('id', 'parent_id', 'type', 'title', 'slug')->first();
            }
                                
        }else{
            $page = isset($request->pagesize) ? $request->pagesize : 25;
            $query = Products::with(['categories', 'category', 'unitedetail', 'locations.location'])->orderBy('title');

            if ($request->has('criteria')) {
                if ($request->criteria == 'title') {
                    $query->where('products.title', 'LIKE', "%" . $request->keyword . "%");
                    #dd($query->get()->toArray());
                }
                if ($request->criteria == 'category') {
                    $query->whereHas('categories', function ($q) use ($request) {                        
                        $q->where('products_categories.category_id', $request->keyword);
                    });
                }
            }            

            if($request->has('page') && !$request->has('list')){
                $page = $request->page;
            }

            if($request->has('id')){
                $query->where('products.id', $request->id);
                $page = 0;
            }

            $query->orderBy("title");                            
            
            if ($page == 0) {
                $products = $query->get();
            } else {
                $products = $query->paginate($page);
            }            

            $products->transform(function ($product) {
                $location = Location::find(my_location()->id);
            
                if ((int) $location->is_parent === 1) {
                    $l = $product->locations;
                } else {
                    $l = $product->locations->where('location_id', my_location()->id)->values(); // ✅ Correction ici
                }
            
                $product->locations = $l->map(function ($location) use ($product) {
                    $location['sstatus'] = $location->status === 'active';
            
                    $location['unite'] = [
                        'id' => $product->unite_id,
                        'title' => $product->unite,
                    ];
                    $location['purchase'] = [
                        'price' => 0
                    ];
            
                    $location['price'] = ProductCustomerPrice::where('location_id', $location->location_id)
                        ->where('product_id', $product->id)
                        ->first();
                    $location['stock'] = ProductStock::where('location_id', $location->location_id)
                        ->where('product_id', $product->id)
                        ->first();
            
                    return $location->toArray();
                });
            
                return $product;
            });
            
        }                

        return response()->json([
            'status' => 'success',
            'products' => $products->toArray()
        ]);
    }

    public function export(Request $request){
        $filters = [];
        #dd($request->all());
        if($request->has('location') && $request->location['id'] != 0){
            $filters['location'] = $request->location['id'];
        }

        if($request->has('category') && isset($request->category['id'])){
            $filters['category'] = $request->category['id'];
        }

        if($request->has('stock') && isset($request->stock['criteria']['value'])){
            $filters['stock'] = [
                'criteria' => $request->stock['criteria'],
                'value' => $request->stock['value']
            ];
        }
        
        $groups = CustomerGroup::all();
        $products = [['Ref', 'Catégorie', 'Désignation', 'Prix achat', 'CMUP', 'Gestion stock', 'Stock']];                

        // Ajout des colonnes pour les stocks et prix de vente
        foreach ($groups as $group) {
            $products[0][] = 'Prix vente ' . strtolower($group->title);
        }

        // Récupération des produits avec relations        
        $query = ProductLocation::with(['product.categories'])
                    ->when(!empty($filters), function ($q) use ($filters) {
                        // Filter by location if provided
                        if (!empty($filters['location'])) {
                            $q->where('location_id', $filters['location']);
                        }
                        
                        // Filter by category if provided
                        if (!empty($filters['category']) && is_numeric($filters['category'])) {
                            $q->whereHas('product.categories', function ($q) use ($filters) {
                                $q->where('category_id', $filters['category']);
                            });
                        }

                        // Filter by stock condition if provided
                        if (!empty($filters['stock'])) {
                            $q->whereHas('product.stock', function ($q) use ($filters) {
                                // Appliquer le filtre location_id sur ProductStock si fourni
                                if (!empty($filters['location'])) {
                                    $q->where('location_id', $filters['location']);
                                }
                                #dd($stockCondition, $filters['stock']['value']);
                        
                                // Appliquer la condition sur le stock
                                $condition = $filters['stock']['criteria']['value']; // 'equal', 'superior', 'superiorEqual', 'inferior', 'inferiorEqual'                
                                $value = $filters['stock']['value'];
                                
                                switch ($condition) {
                                    case 'equal':
                                        $q->where('stock', '=', $value);
                                        break;
                                    case 'superior':
                                        $q->where('stock', '>', $value);
                                        break;
                                    case 'superiorEqual':
                                        $q->where('stock', '>=', $value);
                                        break;
                                    case 'inferior':
                                        $q->where('stock', '<', $value);
                                        break;
                                    case 'inferiorEqual':
                                        $q->where('stock', '<=', $value);
                                        break;
                                    case 'between':
                                        $q->whereBetween('stock', explode(',', $value));                            
                                        break;
                                    default:
                                        // Condition par défaut (facultatif)
                                        break;
                                }
                            });
                        }                        
                    })
                    ->orderBy('products_locations.product_id') // Assurez-vous d'ordonner par un champ valide
                    ->get()
                    ->groupBy('location_id');                                    

        foreach ($query as $location_id => $location) {
            $products[] = [Location::find($location_id)->title];

            foreach ($location as $key => $product) {                
                $category = $product->product->categories->pluck('title')->implode(' - ');

                $row = [
                    $product->product->reference,
                    $category,
                    $product->product->title,
                    $product->frns_price,
                    $product->cmup,
                ];

                $prod = Products::where('id', $product->product_id)->with(['stock', 'dataprice'])->first();                
                $stock = $prod->stock->where('location_id', $location_id)->pluck('stock')->toArray();
                $row[] = $prod->stock_management ? 'Oui' : 'Non';
                $row[] = $stock[0];
                                
                foreach ($groups as $key => $group) {
                    $gp = $prod->dataprice
                                ->where('location_id', $location_id)
                                ->where('group_id', $group->id)
                                ->sortBy('qty_min')->pluck('price')->toArray();

                    $row[] = isset($gp[0]) ? $gp[0] : 0;
                }
                
                $products[] = $row;
            }
        }

        if($request->type == 'export'){
            Excel::store(new ProductExport($products), 'products.csv', 'public');            
            $link = asset('storage/products.csv');
            $type = 'Exportation';                    
        }else{
            $pdf = (new ProductService())->printdocument($products);            
            $link = $pdf['url'];
            $type = 'Impréssion';
        }

        return response()->json([
            'status' => 'success',
            'message' => "$type éffectuée avec succès.",
            'url' => $link
        ]);
    }

    public function destroy($id)
    {
        Products::find($id)->delete();
        return response()->json([
            'status' => 'success',
            'message' => 'Suppréssion éffectuée avec succès.',
        ]);
    }

    public function create(Request $request)
    {
        try {
            $request->validate([
                'title' => 'required',
                #'price' => ['required', 'numeric'],
                'category.id' => 'required'
            ]);

            DB::beginTransaction();

            $category = Category::find($request->category['id']);            
            $code = is_null($category->code) ? '' : $category->code;
            $numero = ProductService::numero($code, $category->id);

            $user = Auth::user();

            $product = Products::create([
                'reference' => $numero['reference'],
                'numero' => $numero['numero'],
                'title' => $request->title,
                'unite_id' => $request->unite['id'],
                'unite' => $request->unite['title'],
                'price' => 0,
                'user_id' => $user->id,
                'username' => $user->name,
                'stock_management' => $request->stock_management == true,
                'status' => $request->status['value'],
                'created_at' => date_now(),
                'updated_at' => date_now(),
            ]);

            $id = $product->id;
            $slug = "$id-" . generateString(12);
            $product->slug = $slug;
            $product->position = DB::raw('position + 1');
            $product->save();

            if(!is_null($category->parent_id)){
                ProductCategory::create([
                    'product_id' => $id,
                    'category_id' => $category->parent_id,
                    'pple' => 1,
                    'created_at' => date_now(),
                    'updated_at' => date_now(),
                ]);
            }

            ProductCategory::create([
                'product_id' => $id,
                'category_id' => $category->id,
                'pple' => is_null($category->parent_id) ? 1 : 0,
                'created_at' => date_now(),
                'updated_at' => date_now(),
            ]);

            $group = CustomerGroup::where('is_default', 1)->first();            
            $sites = Location::where('type', 'site')->get();

            foreach ($sites as $key => $site) {
                ProductLocation::create([
                    'product_id' => $id,
                    'location_id' => $site->id, 
                    'status' => $request->status['value'],
                    'created_at' => date_now(),
                    'updated_at' => date_now(),
                ]);

                ProductCustomerPrice::create([
                    'product_id' => $id,
                    'group_id' => $group->id,
                    'location_id' => $site->id,
                    'qty_min' => 0,
                    'qty_max' => 0,
                    'price' => 0, #$request->price,
                    'created_at' => date_now(),
                    'updated_at' => date_now(),
                ]);

                ProductStock::create([
                    'product_id' => $id,
                    'location_id' => $site->id,
                    'stock' => 0,
                    'created_at' => date_now(),
                    'updated_at' => date_now(),
                ]);
            }

            DB::commit();

            $product = Products::with('categories', 'category', 'unitedetail', 'dataprice')->find($id)->first();
           
            return response()->json([
                'status' => 'success',
                'product' => [
                    'data' => $product,
                    'url' => route('app.catalogs.product.edit', ['slug' => $slug])
                ]
            ]);
        } catch (\Throwable $th) {
            DB::rollBack();

            throw $th;
        }
    }

    public function edit(String $slug, Request $request)
    {
        $categories = Category::recursivescategories();
        $unites = Unite::select('id', 'title')->get();
        $groups = CustomerGroup::select('id', "title", "rate_type", "rate_value")->get();
        $frns = BusinessContact::where('category', 'supplier')->select('id', 'company')->get();
        $locations = Location::where('status', 'active')->select('id', 'parent_id', 'type', 'title', 'slug')->get();        

        if($request->has('location')){
            $location_id = $request->location;
        }else{
            $location_id = my_location()->id;
        }
        
        $product = ProductService::products(['location' => $location_id, 'slug' => $slug])->first();
        $product['location'] = Location::where("id", $location_id)->select('id', 'parent_id', 'type', 'title', 'slug')->first();         
        
        if($request->ajax()){
            return response()->json([
                'status' => 'success',
                'groups' => $groups,
                'product' => $product->toArray(),
                "categories" => $categories,
                "unites" => $unites,
                "frns" => $frns,
                "locations" => $locations,
                "settings" => settings(),
                "menu" => config('catalog.menu.menu')
            ]);
        }

        return view('catalogs::product.edit');
    }

    public function update_info(Request $request)
    {
        try {            
            DB::beginTransaction();
            $id = $request->id;

            $type = json_decode($request->type);            
            $unite = json_decode($request->unite);
            $status = $request->status;

            $daty = $request->expiration_date;
            $daty = $daty ? date('Y-m-d', strtotime($daty)) : null;

            $location = json_decode($request->location);            
            $location_id = $location->id;            
            Products::where('id', $id)->update([
                'title' => $request->title,
                'stock_management' => $request->stock_management == true,
                'type' => $type->value,
                'unite_id' => $unite->id,
                'unite' => $unite->title,
                'updated_at' => date_now()
            ]);

            if ($request->hasFile('file') && $request->file('file')->isValid()) {
                $image = $request->file('file');

                $imageData = (new Images('images/products'))->image_upload($image, [
                    'width' => 220,
                    'height' => 240,
                ]);

                Products::where('id', $id)->update([
                    'image' => $imageData['filename']
                ]);
            }

            $category = json_decode($request->category);
            $pple = ProductCategory::where('product_id', $id)->where('pple', 1)->first();            
            if ($category->id != $pple->category_id) {
                $_category = Category::find($category->id);
                $prod = Products::find($id);
                $reference = auto_number("product", $prod->numero);

                if (strpos($reference, 'CATEGORY') !== false) {
                    $reference = str_replace('CATEGORY', $_category->code, $reference);
                }

                $prod->reference = $reference;
                $prod->save();
            }

            $categories = json_decode($request->categories);            
            ProductCategory::where('product_id', $id)->delete();                                
            ProductCategory::create([
                'product_id' => $id,
                'category_id' => $category->id,
                'pple' => 1,
                'created_at' => date_now(),
                'updated_at' => date_now(),
            ]);
            
            ProductCategory::create([
                'product_id' => $id,
                'category_id' => $categories->id,                    
                'created_at' => date_now(),
                'updated_at' => date_now(),
            ]);

            #mise à jour info pour site selectionné            
            $frns = json_decode($request->frns);
            #dd($request->all());
            ProductLocation::where('product_id', $id)->where('location_id', $location_id)->update([
                'description' => $request->description,
                'barcode' => $request->barcode ?? "",
                'expiration_date' => $daty,                
                'reorder_level' => $request->reorder_level,
                'status' => $status ? 'active' : 'inactive',
                'frns_id' => $frns->id, #
                'frns' => $frns->company, #
                'updated_at' => date_now()
            ]);
            #mise à jour info pour site selectionné

            DB::commit();

            $product = $this->product($location_id, $id);            
            return response()->json([
                'status' => 'success',
                'message' => message()['update'],
                'product' => [
                    'data' => $product,
                    'url' => route('app.catalogs.product.edit', ['slug' => $product->slug])
                ]
            ]);
        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }

    public function update_price(Request $request)
    {
        try {            
            $id = $request->id;
            $slug = $request->slug;

            $location = $request->location;            
            $location_id = $location['id'];

            if ($request->type == 'frns') {
                DB::beginTransaction();

                $frns = $request->frns;
                $price = $frns['price']['ht'];
                ProductLocation::where('product_id', $id)->where('location_id', $location_id)->update([
                    'frns_id' => $frns['id'],
                    'frns' => $frns['company'],
                    'frns_is_tva_inclusive' => $frns['is_tva_inclusive'],
                    'frns_tva' => $frns['tva']['rate'],
                    'frns_price' => $price,
                    'updated_at' => date_now()
                ]);

                $exist = ProductSupplierPrice::where('product_id', $id)->where('supplier_id', $frns['id'])
                    ->latest()
                    ->first();

                // Vérifier si l'enregistrement existe et si les valeurs sont différentes
                if (!$exist || $exist->price != $price) {
                    // Insérer un nouvel enregistrement si les valeurs sont différentes
                    ProductSupplierPrice::create([
                        'product_id' => $id,
                        'supplier_id' => $frns['id'],
                        'price' => $price,
                        'created_at' => date_now(),
                        'updated_at' => date_now(),
                    ]);
                }

                DB::commit();
            } else {
                DB::beginTransaction();

                $data['price_variant'] = $request->variant;
                $data['is_tva_inclusive'] = $request->is_tva_inclusive;
                $data['tva_rate'] = $request->tva_rate;

                if (!$request->variant) {                    
                    ProductLocation::where('product_id', $id)->where('location_id', $location_id)->update($data);                    

                    ProductCustomerPrice::where('product_id', $id)->delete();
                    foreach ($request->priceGroup as $group => $price) {
                        ProductCustomerPrice::create([
                            'group_id' => $group,
                            'location_id' => $location_id,
                            'product_id' => $id,
                            'qty_min' => 0,
                            'qty_max' => 0,
                            'price' => $price['ht'],
                            'created_at' => date_now(),
                            'updated_at' => date_now(),
                        ]);
                    }
                } else {
                    ProductCustomerPrice::where('product_id', $id)->delete();
                    $variants = $request->variant_price;
                    
                    foreach ($variants as $k => $item) {
                        foreach ($item['price']['group'] as $group => $prix) {
                            ProductCustomerPrice::create([
                                'location_id' => my_location()->id,
                                'group_id' => $group,
                                'product_id' => $id,
                                'qty_min' => $item['qty']['min'],
                                'qty_max' => is_null($item['qty']['max']) ? 999999999 : $item['qty']['max'],
                                'price' => $prix['ht'],
                                'created_at' => date_now(),
                                'updated_at' => date_now(),
                            ]);
                        }
                    }
                }

                DB::commit();
            }

            $product = $this->product($location_id, $id);
            return response()->json([
                'status' => 'success',
                'message' => message()['update'],
                'product' => [
                    'data' => $product,
                    'url' => route('app.catalogs.product.edit', ['slug' => $slug])
                ]
            ]);
        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }

    public function update_location(Request $request){
        try {
            $request->validate([
                'depot.id' => 'required'
            ]);

            $id = $request->id;
            $site = $request->location;
            $depot = $request->depot;
            $emplacement = $request->emplacement;
            $location_id = $site['id'];            

            $parent = ProductLocation::where('product_id', $id)->where('location_id', $location_id)->first();
            $me = ProductSubLocation::where([
                'product_id' => $id,                
                'product_location_id' => $parent->id,
                'parent_location' => $depot['id'],
            ]);
            
            if(!is_null($me->first()) && !empty($emplacement)){
                $me->update([                                                            
                    'location_id' => $emplacement['id'],
                    'location_type' => 'emplacement',                    
                    'updated_at' => date_now()
                ]);
            }else{
                ProductSubLocation::create([
                    'product_id' => $id,
                    'product_location_id' => $parent->id,
                    'parent_location' => $depot['id'],
                    'location_id' => !empty($emplacement) ? $emplacement['id'] : null,
                    'location_type' => 'emplacement',
                    'created_at' => date_now(),
                    'updated_at' => date_now()
                ]);
            }            

            $product = $this->product($location_id, $id);
            return response()->json([
                'status' => 'success',
                'message' => message()['update'],
                'product' => [
                    'data' => $product,
                    'url' => route('app.catalogs.product.edit', ['slug' => $product->slug])
                ]
            ]);

        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }

    //HS
    public function hs_motif(){
        return response()->json([
            'status' => 'success',
            'motifs' => ProductService::hsMotif()
        ]);
    }

    public function hs_motif_store(Request $request){
        try {
            DB::beginTransaction();

            $product = $request->product;
            $motif = $request->motif;
            $location = my_location();
            $location_id = $location->id;

            $qty = $request->qty;                            

            if((int)$request->motif['id'] == 0){
                $motif = HS::create([
                    'title' => $request->other,
                    'updated_at' => date_now(),
                    'created_at' => date_now(),
                ])->toArray();
            }            

            $hs = ProductHS::create([
                'product_id' => $product['id'],
                'product' => $product['title'],

                'location_id' => $location->id,
                'location' => $location->title,

                'motif_id' => $motif['id'],
                'motif' => $motif['title'],
                'qty' => $qty,

                'updated_at' => date_now(),
                'created_at' => date_now(),
            ]);
            $token = $hs->id ."-". generateString(16);
            $hs->token = $token;
            $hs->save();

            $stock = new StockService();                    
            
            $prod = ProductService::products(['id' => $product['id']])->first();
            $stock_hs = $prod->stock_hs->sum('qty');
            
            $stock_actual = $prod->stock[0]->stock;
            $stock_final = (float)$stock_actual;

            //dd($stock_actual, $qty, $stock_final);

            $where = [
                'product_id' => $product['id'],
                'location_id' => $location_id
            ];
            $stock->createUpdateControl([
                'type' => 'hs',
                'where' => $where,
                'location_id' => $location_id,
                'product_id' => $product['id'],
                'product_name' => $product['title'],
                'stock_actual' => $stock_actual,
                'quantity' => $qty,
                'stock_final' => $stock_final,
                'title' => "HS: " . $motif['title'],
            ]);

            $stock->logStockStory([
                'product_id' => $product['id'],
                'product_name' => $product['title'],
                'location_id' => $location_id,
                'title' => "HS: ". $motif['title'],   
                'stock_actual' => $stock_actual,
                'quantity' => $qty,
                'stock_final' => $stock_final,
                'token' => $token,
            ]);

            /*$stock->update([
                'product_id' => $product['id'], 
                'location_id' => $location_id, 
                'quantity' => $qty, 
                'price' => 0
            ], 'exit');*/

            DB::commit();

            return response()->json([
                'status' => 'success',
                'message' => 'Produit mis hors usage avec succès.'
            ]);
        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }
    //HS

    private function product(int $location_id, int $productid){
        $product = ProductService::products(['location' => $location_id, 'id' => $productid])->first();
        $product['location'] = Location::where("id", $location_id)->select('id', 'parent_id', 'type', 'title', 'slug')->first();

        return $product;
    }
}
