<?php

namespace modules\crm\services;

use modules\crm\Models\BusinessContact;
use modules\crm\Models\CustomerGroup;

class CrmService
{
    public static function customers(array $filters = [], int $pagination = 0)
    {
        $filters['category'] = 'customer';
        return self::getdata($filters, $pagination);
    }    
    
    public static function suppliers(array $filters = [], int $pagination = 0)
    {        
        $filters['category'] = 'supplier';
        return self::getdata($filters, $pagination);
    }    

    protected static function getdata(array $filters = [], int $pagination = 0){        
        $query = BusinessContact::query();        

        if (!empty($filters)) {                            
            self::applyFilters($query, $filters);
        }        

        $customers = $pagination == 0 ? $query->get() : $query->paginate($pagination);
        #dd($customers, $filters);
        
        $customers->transform(function($customer) use ($filters){
            $customer = $customer->toArray();
            

            if(isset($filters['category']) and $filters['category'] == 'customer'){
                $name = (int)$customer['group']['b2b'] == 1 ? $customer['company'] : $customer['lastname'] . ' ' . $customer['firstname'];
            }else{
                $name = !is_null($customer['company']) ? $customer['company'] : $customer['lastname'] . ' ' . $customer['firstname'];
            }

            $customer['title'] = $name;

            $customer['invoice'] = [];
            $customer['order'] = [];
            $customer['delivery'] = [];
            $customer['return'] = [];
            $customer['quote'] = [];
            $customer['rap'] = 0;

            #dd($customer, $name);

            return $customer;
        });           

        #dd($customers->toArray(), $filters);
        
        return $customers;
    }

    // Appliquer les filtres de recherche
    private static function applyFilters($query, array $filters)
    {
        if(isset($filters['category'])){
            if($filters['category'] == 'customer'){
                $query->with(['group']);
            }
            $query->where('category', $filters['category']);
        }
        if (isset($filters['id'])) {
            $query->where('business_contacts.id', $filters['id']);
        }
        if (isset($filters['slug'])) {
            $query->where('slug', $filters['slug']);
        }        
        if (isset($filters['location'])) {
            $query->where('location_id', $filters['location']);
        }        
        if (isset($filters['group_id'])) {
            $query->where('group_id', $filters['group_id']);
        }        

        if (isset($filters['keyword']) && isset($filters['criteria'])) {
            $query->where("products.{$filters['criteria']}", 'LIKE', "%{$filters['keyword']}%");
        }

        if(isset($filters['reference'])){
            $query->where('reference', $filters['reference']);
        }
        if(isset($filters['name'])){
            $query->where('lastname', "LIKE", "%".$filters['name']."%")
                    ->orWhere('firstname', "LIKE", "%".$filters['name']."%")
                    ->orWhere('company', "LIKE", "%".$filters['name']."%");

        }
        if(isset($filters['email'])){
            $query->where('email', $filters['email']);
        }
        if(isset($filters['phone'])){
            $query->where('phone', $filters['phone']);
        }
    }
}