<?php

namespace modules\purchases\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use modules\catalogs\Models\Unite;
use modules\crm\Models\BusinessContact;
use modules\crm\services\CrmService;
use modules\sales\Models\purchaseDocLog;
use modules\sales\Models\purchaseDocSetting;
use modules\sales\Models\purchaseDocStatus;
use modules\sales\Models\purchaseDocStatusLog;
use modules\sales\Models\purchaseDocument;
use modules\sales\services\PurchaseDocService;

class purchaseDocumentController extends Controller
{
    /**
     * Display a listing of the resource.     
    public function index(Request $request)
    {
        $type = $request->type;
        purchaseDocument::where('validate', 0)->delete();
        $status = (new PurchaseDocService())->all_status($type);
        $param = [];
        if(isset($request->status)){
            $p = explode('@', $request->status);
            $param['status'] = $p[0];
        }

        $status['data'] = purchaseDocStatus::where('type', 'invoice')->get();                
        return view('purchases::documents.index', [
            'status' => $status,
            'param' => $param
        ]);
    }   
    
    public function create(string $type)
    {
        try {
            DB::beginTransaction();            
            
            $date_release = date_now()->addDays(settings()['document_release_date']->value);        
            $supplier = BusinessContact::where('is_default', 1)->where('category', 'supplier')->first();
            $name = is_null($supplier->company) ? $supplier->lastname : $supplier->company;

            $user = Auth::user();

            $location = my_location();
            $document = purchaseDocument::create([ 
                'location_id' => $location->id,
                'location' => $location->title,
                "document_type" => $type,
                "supplier_id" => $supplier->id,
                "supplier" => $name,
                "user_id" => $user->id,
                "username" => $user->name,        
                "edited_by"  => $user->id,
                "edited_name" => $user->name,
                "document_date" => date_now()->format('Y-m-d'),
                "document_release_date" => $date_release->format('Y-m-d'),
                "created_at" => date_now(),
                "updated_at" => date_now()
            ]);                              

            $document_id = $document->id; 
            $slug = $document_id ."-".generateString(16);
            $document->slug = $slug;
            $document->save();
    
            $status = purchaseDocStatus::where('type', 'invoice')->where('use_default', 1)->first();            

            $document_status = purchaseDocStatusLog::create([
                'document_id' => $document_id,
                "reference" => $document->reference,
                'document_status_id' => $status->id,
                'document_status' => $status->title,
                'background' => $status->background,
                'color' => $status->color,
                'icon' => $status->icon,
                'user_id' => $user->id,
                "username" => $user->name,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);

            #dd($document_status);

            $doc = PurchaseDocService::documenttype()[$type];
            purchaseDocLog::create([
                "document_id" => $document_id,
                "reference" => $document->reference,
                "document_status_id" => $status->id,
                "document_status" => $status->title,
                "title" => "Création $doc",
                "user_id" => $user->id,
                "username" => $user->name,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);
            
            DB::commit();            

            return redirect()->route('app.sales.documents.edit', ['slug' => $slug, 'type' => $type]);
        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }
    
    public function edit(String $type, String $slug, Request $request)
    {
        $document = purchaseDocument::with('status')->where('slug', $slug)->first();
        #dd($document, $slug);

        $current_status = $document->status[0]->status_id;
        $status = [];
        
        switch((int)$current_status){
            case 1:
                $status = [1, 4];
                break;
            case 2:
                $status = [1, 2];
                break;
            case 3:
                $status = [1, 2, 3];
                break;
            default:
                $status = [];
                break;
        }        
        $xstatus = purchaseDocStatus::where('type', $type)
                    ->select('id', 'title', 'background', 'color', 'icon', 'description')
                    ->whereNotIn('id', $status)->get();        
        $_status = array_values($xstatus->toArray());  
        $suppliers = CrmService::suppliers();

        if(isset($request->tab)){
            $tab = $request->tab;

            if($tab == 'historiques'){                
                return view('purchases::documents.story', [
                    'document' => $document,            
                    'unites' => Unite::select('id', 'title', 'is_default')->get(),
                    'status' => $_status,
                    'suppliers' => $suppliers
                ]);
            }elseif($tab == 'paiements'){
                $settings = purchaseDocSetting::all()->keyBy('name');
                return view('purchases::documents.payment', [
                    'document' => $document,
                    'documentsettings' => $settings,
                    'status' => $_status
                ]);
            }elseif($tab == 'emails'){   
                return view('purchases::documents.email', [
                    'document' => $document,                    
                    'status' => $_status,
                    'suppliers' => $suppliers
                ]);
            }elseif($tab == 'footer'){
                $settings = purchaseDocSetting::all()->keyBy('name');                
                return view('purchases::documents.InvoiceFooter', [
                    'document' => $document,
                    'document_settings' => $settings,
                    'status' => $_status,
                    'suppliers' => $suppliers
                ]);
            }
        }
        
        $title = PurchaseDocService::documenttype()[$document->document_type];        
        return view('purchases::documents.detail', [
            'title' => $title,
            'document' => $document,            
            'unites' => Unite::select('id', 'title', 'is_default')->get(),
            'status' => $_status,
            'suppliers' => $suppliers
        ]);
    }

    public function getdata(Request $request) {
        $type = $request->type;
        $page = isset($request->pagesize) ? $request->pagesize : 25;
        
        $data = ['validate' => 1];
        
        if($request->has('slug')){
            $data['slug'] = $request->input('slug');
            unset($data['validate']);
            $page = 0;
        }

        if(isset($request->status)){   
            $status = explode("@", $request->status);            
            if((int)$status[0] != 0){
                $data['status'] = $status[0];
            }
        }
        
        $documents = (new PurchaseDocService())->documents($type, $data, $page);
        return response()->json([
            'status' => 'success',
            'documents' => $documents->toArray()
        ]);
    }

    public function store_info(Request $request){
        try {
            #dd($request->details);
            #dd($request->all());

            $validator = [
                'supplier.id' => 'required',                
                'details' => 'required|array|min:1'
            ];
            $request->validate($validator);

            DB::beginTransaction();
            $type = $request->type;                                

            $supplier_id = $request->supplier['id'];
            $supplier = CrmService::suppliers()->where('id', $supplier_id)->first();
            $address = $request->address;

            $document_id = $request->id;
            $date_document = $request->document_date;
            $date_release = $request->document_release_date;
            $linkto = $request->linked_to;

            $document = purchaseDocument::find($document_id);
            $user = Auth::user();

            $document = purchaseDocument::find($document_id);            
            
            $slug = $document->slug;
            $document->update([

                "link_to" => $linkto['value'],

                "document_id" => $linkto['value'] == 'none' ? null : '',
                "numero" => $linkto['value'] == 'none' ? null : '',
                "reference" => $linkto['value'] == 'none' ? null : '',
                "document_date" => $date_document,
                "document_release_date" => $date_release,

                "supplier_id" => $supplier_id,
                "supplier" => $supplier['title'],
                "supplier_email" => $supplier['email'],
                "supplier_phone" => $supplier['phone'],
                "supplier_address" => $address,

                "document_for" => isset($request->invoice_type) && $request->invoice_type == 1 ? 'site' : 'supplier',
            ]);

            if($type == 'invoice'){
                $invoiceType = $request->invoice_type ? 'site' : 'supplier';
                
                $exist = InvoiceType::where('invoice_id', $document_id)->first();
                if(is_null($exist)){
                    InvoiceType::create([
                        "invoice_id" => $document_id,
                        "invoice_type" => $invoiceType,
                        'delivery_price' => $request->delivery,
                        "created_at" => date_now(),
                        "updated_at" => date_now(),
                    ]);
                }else{
                    InvoiceType::where("invoice_id", $document_id)->update([
                        "invoice_type" => $invoiceType,
                        'delivery_price' => $request->delivery,
                        "updated_at" => date_now(),
                    ]);
                }
            }

            $details = $request->details;
            purchaseDocumentDetail::where('document_id', $document_id)->delete();
            foreach ($details as $key => $item) {
                $product_id = null;
                $designation = $item['col']['designation']['value'];                

                $product_image = null;
                if($item['type'] == 'product' || $item['type'] == 'container'){
                    $designation = $item['col']['designation']['value']['title'];
                    $product_id = $item['col']['designation']['value']['id'];

                    if($item['type'] == 'product'){
                        $product = Products::find($product_id);
                        $product_image = $product->image;
                    }
                }
                if($item['type'] == 'saut-page') {
                    $designation = 'saut-page';
                }
                if($item['type'] == 'title' || $item['type'] == 'texte') {
                    $designation = $item['col']['text'];
                }                
                
                if(!is_null($designation)){
                    $qty = $item['col']['qte']['value'];                
                    $unite = $item['col']['unite']['value'];
                    #dd($unite);

                    $price = [];
                    if(isset($item['col']['prix'])){
                        $price = $item['col']['prix'];
                    }

                    #dd($price);

                    if($item['type'] == 'sous-total'){
                        $htprice = $item['col']['sousTotal'];
                    }else{
                        $htprice = !empty($price) ? $price['ht']['price'] : 0;
                    }


                    purchaseDocumentDetail::create([
                        'document_id' => $document_id,
                        'row_type' => $item['type'],
                        'product_id' => $product_id,
                        'product' => $designation,
                        'product_image' => $product_image,
                        'qty' => $qty,
                        'unite_id' => is_array($unite) ? $unite['id'] : 0,
                        'unite' => is_array($unite) ? $unite['title'] : 0,
                        'price_ht' => $htprice,
                        'discount_by' => !empty($price) ? ($price['remise']['by'] == '%' ? 'percent' : 'amount')  : 'percent',
                        'discount_rate' => !empty($price) ? $price['remise']['rate'] : 0,
                        'discount_price' => !empty($price) ? $price['remise']['price'] : 0,
                        'tva_rate' => !empty($price) ? $price['tva']['rate'] : 0,
                        'tva_price' => !empty($price) ? $price['tva']['price'] : 0,
                        'price_ttc' => !empty($price) ? $price['ttc'] : 0,
                        'created_at' => date_now(),
                        'updated_at' => date_now(),
                    ]);
                }
            }
            
            purchaseDocument::where('id', $document_id)->update([
                "validate" => 1,

                "edited_by" => $user->id,
                "edited_name" => $user->name,                

                "discount_by" => null,
                "discount_rate" => 0,
                "discount_price" => $request->total['remise'],

                "tva_rate" => 0,
                "tva_price" => $request->total['tva'],
                "total_ht" => $request->total['ht'],
                "total_ttc" => $request->total['ttc'],

                "updated_at" => date_now()
            ]);

            $status = $document->status[0];
            $existStatusLog = purchaseDocStatusLog::where([
                'document_id' => $document_id,
                'document_status_id' => $status->document_status_id,
            ])->first();

            if(!is_null($existStatusLog)){
                purchaseDocStatusLog::create([
                    'document_id' => $document_id,
                    "reference" => $document->reference,
                    'document_status_id' => $status->document_status_id,
                    'document_status' => $status->document_status,
                    'background' => $status->background,
                    'color' => $status->color,
                    'icon' => $status->icon,
                    'user_id' => $user->id,
                    "username" => $user->name,
                    "created_at" => date_now(),
                    "updated_at" => date_now(),
                ]); 
            }
                    
            purchaseDocLog::create([
                "document_id" => $document_id,
                "reference" => $document->reference,
                "document_status_id" => $status->document_status_id,
                "document_status" => $status->document_status,
                "title" => "Modification ". PurchaseDocService::documenttype()[$type],
                "user_id" => $user->id,
                "username" => $user->name,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);            

            DB::commit();

            $document = (new PurchaseDocService())->documents($type, ['slug' => $slug])->first();
            return response()->json([
                'status' => 'success',
                'message' => 'document saved successfully',
                'document' => $document
            ]);
        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }

    public function status(Request $request)
    {
        try {
            #dd($request->all());
            DB::beginTransaction();
            
            $document_id = $request->id;
            $document = purchaseDocument::find($document_id);
            $slug = $document->slug;
            
            $status = $request->status; 
            $reference = $document->reference;

            if((int)$status['use_default'] != 1 || (int)$status['cancelled'] != 1){
                if(is_null($document->numero)){
                    $numero = (new PurchaseDocService())->numero($document->document_type);                      
                    #dd($numero);
                    $reference = $numero['reference'];
                    purchaseDocument::where('id', $document_id)->update([
                        "reference" => $reference,
                        "numero" => $numero['index'],
                    ]);

                    (new PurchaseDocService())->duplicateParentInvoice($document_id, 'decrease');
                }
            }

            purchaseDocStatusLog::create([
                'document_id' => $document_id,
                'reference' => $reference,
                'document_status_id' => $status['id'],
                'document_status' => $status['title'],
                'background' => $status['background'],
                'color' => $status['color'],
                'icon' => $status['icon'],                
                "user_id" => Auth::user()->id,
                "username" => Auth::user()->name,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);            

            $doc = PurchaseDocService::documenttype()[$document->document_type];
            purchaseDocLog::create([
                "document_id" => $document_id,
                "reference" => $reference,
                "document_status_id" => $status['id'],
                "document_status" => $status['title'],
                "title" => "Mise à jour status $doc",
                "user_id" => Auth::user()->id,
                "username" => Auth::user()->name,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);

            #gestion stock

            #gestion stock

            DB::commit();

            $document = (new PurchaseDocService())->documents($document->document_type, ['slug' => $slug]);
            return response()->json([
                'status' => 'success',
                'message' => 'status updated successfully',
                'documents' => $document
            ]);
        } catch (\Exception $th) {
            DB::rollBack();
            throw $th;
        }
    }

    public function payment(Request $request){
        try {
            #dd($request->all());
            
            DB::beginTransaction();

            $user = Auth::user();

            $type = $request->type;            
            $request->validate([
                'amount' => 'required|numeric|not_in:0',                
                'paid_date' => 'required|date',
                'method.id' => 'required'
            ]);

            $document_id = $request->document_id;
            $document = (new PurchaseDocService)->documents($type, ['id' => $document_id])[0];
            #dd($document);
            purchaseDocumentPayment::create([
                "document_id" => $document_id,
                "reference" => $document->reference,
                "user_id" => $user->id,
                "username" => $user->name,
                "payment_method_id" => $request->method['id'],
                "payment_method" => $request->method['title'],
                "amount" => $request->amount,
                "observation" => $request->observation,
                'created_at' => date_now(),
                'updated_at' => date_now(),
            ]);

            $currentStatus = $document->status[0];

            $status = purchaseDocStatus::find($currentStatus->document_status_id);            


            $reference = $document->reference;
            if(is_null($reference)){
                $numero = (new PurchaseDocService())->numero('invoice');

                $reference = $numero['reference'];
                purchaseDocument::where('id', $document_id)->update([
                    'numero' => $numero['index'],
                    'reference' => $reference,
                ]);
            }

            $reste = (double)$request->rap - (double)$request->amount;
            if($reste == 0){
                $status = purchaseDocStatus::where('type', $type)->where('pay', 1)->first();
                purchaseDocStatusLog::create([
                    'document_id' => $document_id,
                    "reference" => $reference,
                    'document_status_id' => $status->id,
                    'document_status' => $status->title,
                    'background' => $status->background,
                    'color' => $status->color,
                    'icon' => $status->icon,
                    'user_id' => $user->id,
                    "username" => $user->name,
                    "created_at" => date_now(),
                    "updated_at" => date_now(),
                ]);              
            }

            $doc = PurchaseDocService::documenttype()[$document->document_type];
            purchaseDocLog::create([
                "document_id" => $document_id,
                "reference" => $reference,
                "document_status_id" => $status['id'],
                "document_status" => $status['title'],
                "title" => "Paiement $doc",
                "user_id" => Auth::user()->id,
                "username" => Auth::user()->name,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);

            DB::commit();

            $document = (new PurchaseDocService())->documents($type, ['id' => $document_id])->first();
            return response()->json([
                'status' => 'success',
                'message' => 'save paid successfully',
                'document' => $document
            ]);

        } catch (\Exception $th) {
            DB::rollBack();
            throw $th;
        }
    }*/
}