<?php

namespace modules\sales\services;

use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use modules\catalogs\Models\Products;
use modules\catalogs\services\ProductService;
use modules\catalogs\services\StockService;
use modules\location\Models\Location;
use modules\sales\Models\PurchaseDocument;
use modules\sales\Models\PurchaseDocumentDetail;
use modules\sales\Models\Invoice;
use modules\sales\Models\InvoiceDetail;
use modules\sales\Models\InvoiceType;
use modules\stocks\Models\StockTransfert;
use modules\stocks\Models\StockTransfertDetail;

use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\View;
use modules\sales\Models\purchaseDocStatus;

class PurchaseDocService
{
    
    public static function documenttype(){
        return [
            "invoice" => "Facture",
            "order" => "Bon de commande",
            "delivery" => "Bon de livraison", 
            "return" => "Bon de retour", 
            "credit" => "Avoirs",
        ];
    }

    public function documents(string $type, array $data = [], int $page = 0){
        $relations = ['status', 'details', 'stories', 'payments'];
        if($type == 'invoice'){
            $relations[] = 'invoice_type';
        }
        #dd($relations);

        $res = PurchaseDocument::with($relations)->where('document_type', $type);        

        #dd($res->get(), $type);

        if(!empty($data)){                    
            if(isset($data['validate'])){
                $res->where('purchases_documents.validate', $data['validate']);
            }
            
            if(isset($data['id'])){
                $res->where('purchases_documents.id', $data['id']);
            }
            
            if(isset($data['slug'])){
                $res->where('purchases_documents.slug', $data['slug']);
            }
            
            if(isset($data['supplier_id'])){
                $res->where('purchases_documents.supplier_id', $data['supplier_id']);
            }                    

            if(isset($data['year'])){
                $res->whereDate('created_at', '>=', "{$data['year']['begin']}-10-01")
                    ->whereDate('created_at', '<=', "{$data['year']['end']}-09-30");
            }

            if(isset($data['status'])){
                $ch = $this->status([], ['document_status_id' => $data['status']]);
                $document_id = array_column($ch, 'document_id');
                $res->whereIn('purchases_documents.id', $document_id);
            }
        }

        if($page == 0){
            $documents = $res->orderByDesc('created_at')->get();
        }else{
            $documents = $res->orderByDesc('created_at')->paginate($page);
        }
        
        #dd($documents->toArray());

        $documents->transform(function($item, $key) use ($type){      
            $status = $item->status;
            $item->status = $status;
            $currentStatusId = $status[0]->document_status_id;
            $currentStatus = purchaseDocStatus::find($currentStatusId);
            $item->status[0]['edited'] = (int)$currentStatus->edited == 1;

            $item->current_status = $currentStatusId;
            $used_status = array_column($status->toArray(), "document_status_id");
            $item->used_status = $used_status;
            
            $pstatus = $this->statusUsed($type, $status[0]->document_status_id);
            #dd($pstatus);

            $datastatus = purchaseDocStatus::whereNotIn('id', $pstatus)->where('type', $type)->get();
            
            $item->datastatus = $datastatus;
            
            if((int)$status[0]->document_status_id == 4 OR (int)$status[0]->document_status_id == 5){
                
            }else{
                $release_date = Carbon::parse($item->Purchase_document_release_date)->format('Y-m-d');
                $day_diff = Carbon::now()->diff($release_date);
                
                $item->release_in_days = [
                    'class' => (int)$day_diff->invert == 0 ? "text-blue-700" : "text-red-700", 
                    'text' => (int)$day_diff->invert == 0 ? "Expiré dans {$day_diff->days}j" : "Retard de {$day_diff->days}j",
                    'invert' => $day_diff->invert
                ]; 
            }            
            
            $item->details = $item->details;
            $item->stories = $item->stories;

            $payments = $item->payments;
            $payment = $payments->sum('amount');            

            $item->payments = $payments;
            $item->payment_total = $payment;
            
            $rap = (float)$payment - (float)$item->total_ttc;
            $item->rap = $rap;

            $item->supplier_status = $rap != 0 ? "Impayé" : "Payé";

            return $item;
        });
        #dd($documents);

        $documents->filter(function ($invoice) {
            return $invoice->rap < 0;
        });        
        
        return $documents;
    }

    public function status(array $year = [], array $data = [])
    {
        $bindings = [];        
        $query = "
            WITH RankedStatus AS (
                SELECT
                    document_id,
                    document_status_id,
                    created_at,
                    ROW_NUMBER() OVER (PARTITION BY document_id ORDER BY created_at DESC) AS rn
                FROM
                    purchases_documents_status_logs
            )
            SELECT
                rs.document_id,
                rs.document_status_id,
                rs.created_at,
                i.total_ht,
                i.total_ttc,
                COALESCE(SUM(ip.amount), 0) AS total_paid,
                COALESCE(SUM(ip.amount), 0) - i.total_ttc AS rap
            FROM
                RankedStatus rs
            INNER JOIN
                purchases_documents i ON i.id = rs.document_id
            LEFT JOIN
                purchases_documents_payments ip ON ip.document_id = rs.document_id
            WHERE 
                rs.rn = 1 
                AND i.validate = 1";

        // Add filters dynamically
        if (!empty($data)) {
            if (isset($data['document_status_id'])) {
                if (is_array($data['document_status_id'])) {
                    $placeholders = implode(',', array_fill(0, count($data['document_status_id']), '?'));
                    $query .= " AND rs.document_status_id IN ($placeholders)";
                    $bindings = array_merge($bindings, $data['document_status_id']);
                } else {
                    $query .= " AND rs.document_status_id = ?";
                    $bindings[] = $data['document_status_id'];
                }
            }

            if (isset($data['supplier_id'])) {
                $query .= " AND i.supplier_id = ?";
                $bindings[] = $data['supplier_id'];
            }

            if (isset($data['document_id'])) {
                if (is_array($data['document_id']) && !empty($data['document_id'])) {
                    $placeholders = implode(',', array_fill(0, count($data['document_id']), '?'));
                    $query .= " AND rs.document_id IN ($placeholders)";
                    $bindings = array_merge($bindings, $data['document_id']);
                }
            }
        }

        // Add year-based filtering
        if (!empty($year)) {
            $begin = $year['begin'] . "-10-01";
            $end = $year['end'] . "-09-30";
            $query .= " AND rs.created_at BETWEEN ? AND ?";
            $bindings[] = $begin;
            $bindings[] = $end;
        }

        // Add GROUP BY clause
        $query .= " GROUP BY 
                        rs.document_id, 
                        rs.document_status_id, 
                        rs.created_at, 
                        i.total_ht, 
                        i.total_ttc";

        // Execute the query with bindings
        return DB::select($query, $bindings);
    }


    public function all_status($type){
        $all = $this->documents($type, ['validate' => 1]);
        
        $status['count'][] = [
            "id" => 0,
            "title" => 'Toutes',
            "icon" => null,
            "background" => "#FFFFFF",
            "color" => "#000000",
            "count" => count($all),
            "ht" => $all->sum('total_ht'),
            "ttc" => $all->sum('total_ttc'),
            "paid" => $all->sum('payment_total'),
            "rap" => $all->sum('rap'),
        ];
        
        $xstatus = purchaseDocStatus::where('type', $type)->get();         
        foreach ($xstatus as $item) {
            $_data = $this->status([], ['document_status_id' => $item->id]);            
            
            $status['count'][$item->id] = [
                "id" => $item->id,
                "title" => $item->title,
                "icon" => $item->icon,
                "background" => $item->background,
                "color" => $item->color,
                "count" => count($_data),
                "ht" => array_sum(array_column($_data, 'total_ht')),
                "ttc" => array_sum(array_column($_data, 'total_ttc')),
                "paid" => array_sum(array_column($_data, 'total_paid')),
                "rap" => array_sum(array_column($_data, 'rap')),
            ];
        }

        return $status;
    }

    protected function statusUsed(string $type, int $statusUsedId): array
    {
        $statusMappings = [
            'invoice' => [
                1 => [1, 4],
                2 => [1, 2],
                3 => [1, 2, 3],
                4 => [1, 2, 3, 4],
            ],
        ];

        return $statusMappings[$type][$statusUsedId] ?? [];
    }
    
}