<?php

namespace modules\sales\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use modules\crm\Models\BusinessContact;
use modules\location\Models\Location;

class Invoice extends Model
{
    use HasFactory;

    protected $table = "invoices";
    protected $fillable = [
        'location_id',
        'location',
        "document_type",
        "link_to",
        "accounting_document_id",
        "numero",
        "reference",
        "reference_parent",
        "accounting_document_date",
        "accounting_document_release_date",
        "customer_id",
        "customer",
        "customer_email",
        "customer_phone",
        "customer_address",
        "discount_by",
        "discount_rate",
        "discount_price",
        "tva_rate",
        "tva_price",
        "total_ht",
        "total_ttc",
        "slug",
        "validate",
        "user_id",
        "username",
        "edited_by",
        "edited_name",
        'delivery_price'
    ];

    public function customer(){        
        return $this->belongsTo(BusinessContact::class, 'customer_id');
    }

    public function details()
    {
        return $this->hasMany(InvoiceDetail::class, 'invoice_id', 'id')
            ->with(['category']);
    }
    
    public function payments(){
        return $this->hasMany(InvoicePayment::class, 'invoice_id', 'id');
    }

    public function invoices(array $data = [], int $page = 0){
        $res = Invoice::with(['details', 'payments']);
        if(!empty($data)){
            if(isset($data['id'])){
                $res->where('invoices.id', $data['id']);
            }

            if(isset($data['document_id'])){
                $res->where('invoices.accounting_document_id', $data['document_id']);
            }
            
            if(isset($data['slug'])){
                $res->where('invoices.slug', $data['slug']);
            }
            
            if(isset($data['customer_id'])){
                $res->where('invoices.customer_id', $data['customer_id']);
            }
        }

        if($page == 0){
            $documents = $res->orderByDesc('created_at')->get();
        }else{
            $documents = $res->orderByDesc('created_at')->paginate($page);
        }
        
        $documents->transform(function($item, $key){
            $item->location_id = $item->location_id;
            $item->customer = $item->location;          

            $item->details = $item->details;

            $payments = $item->payments;
            $payment = $payments->sum('amount');            

            $item->payments = $payments;
            $item->payment_total = $payment;
            
            $rap = (float)$payment - (float)$item->total_ttc;
            $item->rap = $rap;

            return $item;
        });

        $documents->filter(function ($invoice) {
            return $invoice->rap < 0;
        });        

        #dd($documents);
        
        return $documents;
    }

}